@@ -10,7 +10,10 @@ use Type::Params qw/signature/;
 use Carp::Always;
 use Carp qw/confess/;
 
-our $VERSION = "0.0.2";
+use parent 'Exporter';  # inherit all of Exporter's methods
+our @EXPORT_OK = qw(anon_requires);
+
+our $VERSION = "0.0.3";
 
 {
     my %compilations_of_types;
@@ -22,31 +25,53 @@ our $VERSION = "0.0.2";
             $package, $symbol, $referent, $attr,
             $data,    $phase,  $filename, $linenum
         ) = @_;
-        if ($symbol eq 'ANON') {
-            local $Carp::Internal{ 'Attribute::Validate' } = 1;
+        if ( $symbol eq 'ANON' ) {
+            local $Carp::Internal{'Attribute::Validate'} = 1;
             confess "Unable to add signature to anon subroutine";
         }
         my $orig_sub = *{$symbol}{CODE};
         my $compiled = $compilations_of_types{$referent};
         if ( !defined $compiled ) {
-            my %extra_options;
-            if ( 'HASH' eq ref $data->[0] ) {
-                %extra_options = %{ shift @$data };
-            }
-            $compiled = signature( %extra_options, positional => $data );
-            $compilations_of_types{$referent} = $compiled;
+            $compilations_of_types{$referent} = _requires_compile_types(@$data);
         }
-        *{$symbol} = sub {
-            local $Carp::Internal{ 'Attribute::Validate' } = 1;
-            eval { $compiled->(@_); };
-            if ($@) {
-                confess _filter_error("$@");
-            }
-            goto &$orig_sub;
-        };
+        *{$symbol} = _requires_new_sub($compilations_of_types{$referent}, $orig_sub);
     }
 }
 
+sub _requires_compile_types {
+    my $data = [];
+    @$data = @_;
+    my %extra_options;
+    if ( 'HASH' eq ref $data->[0] ) {
+        %extra_options = %{ shift @$data };
+    }
+    return signature( %extra_options, positional => $data );
+}
+
+sub anon_requires {
+    my $orig_sub      = shift;
+    if (!defined $orig_sub || 'CODE' ne ref $orig_sub) {
+        die 'Anon requires didn\'t receive a sub';
+    }
+    my $compiled = _requires_compile_types(@_);
+    return _requires_new_sub($compiled, $orig_sub);
+}
+
+sub _requires_new_sub {
+    my ($compiled, $orig_sub) = @_;
+    if (!defined $orig_sub) {
+        die 'Didn\'t receive a sub';
+    }
+    return sub {
+        local $Carp::Internal{'Attribute::Validate'} = 1;
+        eval { $compiled->(@_); };
+        if ($@) {
+            confess _filter_error("$@");
+        }
+        goto &$orig_sub;
+    };
+}
+
 sub _filter_error {
     my $error = shift;
     $error =~ s{at lib/Attribute/Validate.pm line \d+}{}g;
@@ -99,6 +124,18 @@ Receives a list of L<Type::Tiny> types and enforces those types into the argumen
 spec of L<Type::Params> to change the behavior of this module, for example {strictness => 0} as the first argument will allow the user
 to have more arguments than the ones declared.
 
+=head2 anon_requires
+
+    my $say_thing = anon_requires(sub($thing) {
+        say $thing;
+    ), Str);
+
+    my $say_thing = anon_requires(sub($thing) {
+        say $thing;
+    }, \%spec, Str);
+
+Enforces types into anonymous subroutines since those cannot be enchanted using attributes.
+
 =head1 DEPENDENCIES
 
 The module will pull all the dependencies it needs on install, the minimum supported Perl is v5.16.3, although latest versions are mostly tested for 5.38.2
